@@ -4,8 +4,7 @@ from .pytorch.modules import (
     config,
     evaluation,
     graph_construction,
-    graph_embedding_learning,
-    graph_embedding_initialization,
+    graph_embedding,
     loss,
     prediction,
     utils,
