@@ -1,11 +1,11 @@
-from graph4nlp.pytorch.data.dataset import Text2TreeDataset
+from graph4nlp.pytorch.data.dataset import TextToTreeDataset
 
 
 def tokenize_mathqa(str_input):
     return str_input.strip().split()
 
 
-class MathQADatasetForTree(Text2TreeDataset):
+class MathQADatasetForTree(TextToTreeDataset):
     @property
     def raw_file_names(self):
         """3 reserved keys: 'train', 'val' (optional), 'test'. Represent the split of dataset."""
@@ -25,23 +25,21 @@ class MathQADatasetForTree(Text2TreeDataset):
     def __init__(
         self,
         root_dir,
-        # topology_builder,
+        topology_builder,
         topology_subdir,
-        graph_name,
-        static_or_dynamic="static",
-        topology_builder=None,
-        merge_strategy="tailhead",
-        edge_strategy=None,
-        dynamic_init_graph_name=None,
-        dynamic_init_topology_builder=None,
-        dynamic_init_topology_aux_args=None,
         #  pretrained_word_emb_file=None,
         pretrained_word_emb_name="6B",
         pretrained_word_emb_url=None,
         pretrained_word_emb_cache_dir=None,
         val_split_ratio=0,
+        graph_type="static",
+        merge_strategy="tailhead",
+        edge_strategy=None,
         word_emb_size=300,
         share_vocab=True,
+        dynamic_graph_type=None,
+        dynamic_init_topology_builder=None,
+        dynamic_init_topology_aux_args=None,
         enc_emb_size=300,
         dec_emb_size=300,
         min_word_vocab_freq=1,
@@ -81,17 +79,16 @@ class MathQADatasetForTree(Text2TreeDataset):
         # then do the preprocessing and save them.
         super(MathQADatasetForTree, self).__init__(
             root_dir=root_dir,
-            # topology_builder=topology_builder,
+            topology_builder=topology_builder,
             topology_subdir=topology_subdir,
-            graph_name=graph_name,
-            static_or_dynamic=static_or_dynamic,
+            graph_type=graph_type,
             edge_strategy=edge_strategy,
             merge_strategy=merge_strategy,
             share_vocab=share_vocab,
             pretrained_word_emb_name=pretrained_word_emb_name,
             val_split_ratio=val_split_ratio,
             word_emb_size=word_emb_size,
-            dynamic_init_graph_name=dynamic_init_graph_name,
+            dynamic_graph_type=dynamic_graph_type,
             dynamic_init_topology_builder=dynamic_init_topology_builder,
             dynamic_init_topology_aux_args=dynamic_init_topology_aux_args,
             enc_emb_size=enc_emb_size,
