@@ -1,12 +1,9 @@
 import copy
 import torch.nn.functional as F
 
-from graph4nlp.pytorch.modules.graph_embedding_initialization.embedding_construction import (
-    WordEmbedding,
-)
+from graph4nlp.pytorch.modules.graph_construction.embedding_construction import WordEmbedding
 from graph4nlp.pytorch.modules.prediction.generation.decoder_strategy import DecoderStrategy
 from graph4nlp.pytorch.modules.prediction.generation.StdRNNDecoder import StdRNNDecoder
-from graph4nlp.pytorch.modules.utils.generic_utils import wordid2str
 
 from .base import Graph2XBase
 
@@ -35,7 +32,7 @@ class Graph2Seq(Graph2XBase):
     ----------
     vocab_model: VocabModel
         The vocabulary.
-    graph_name: str
+    graph_type: str
         The graph type. Excepted in ["dependency", "constituency", "node_emb", "node_emb_refined"].
     gnn: str
         The graph neural network's name. Expected in ["gcn", "gat", "graphsage", "ggnn"]
@@ -47,7 +44,7 @@ class Graph2Seq(Graph2XBase):
         emb_input_size,
         emb_hidden_size,
         embedding_style,
-        graph_name,
+        graph_type,
         gnn_direction_option,
         gnn_input_size,
         gnn_hidden_size,
@@ -80,7 +77,7 @@ class Graph2Seq(Graph2XBase):
             vocab_model=vocab_model,
             emb_input_size=emb_input_size,
             emb_hidden_size=emb_hidden_size,
-            graph_name=graph_name,
+            graph_type=graph_type,
             gnn_direction_option=gnn_direction_option,
             gnn=gnn,
             gnn_num_layers=gnn_num_layers,
@@ -225,11 +222,7 @@ class Graph2Seq(Graph2XBase):
             It is used for calculating coverage loss.
             The coverage vector.
         """
-        batch_graph = self.graph_initializer(batch_graph)
-        # Yu: dynamic graph modification
-        if hasattr(self, "graph_topology") and hasattr(self.graph_topology, "dynamic_topology"):
-            batch_graph = self.graph_topology.dynamic_topology(batch_graph)
-
+        batch_graph = self.graph_topology(batch_graph)
         return self.encoder_decoder(batch_graph=batch_graph, oov_dict=oov_dict, tgt_seq=tgt_seq)
 
     def translate(self, batch_graph, beam_size, topk=1, oov_dict=None):
@@ -254,49 +247,11 @@ class Graph2Seq(Graph2XBase):
             The results with the shape of ``[batch_size, topk, max_decoder_step]`` containing the word indexes. # noqa
         """
 
-        batch_graph = self.graph_initializer(batch_graph)
-        if hasattr(self, "graph_topology") and hasattr(self.graph_topology, "dynamic_topology"):
-            batch_graph = self.graph_topology.dynamic_topology(batch_graph)
-
+        batch_graph = self.graph_topology(batch_graph)
         return self.encoder_decoder_beam_search(
             batch_graph=batch_graph, beam_size=beam_size, topk=topk, oov_dict=oov_dict
         )
 
-    def post_process(self, decode_results, vocab):
-        pred_ids = decode_results[:, 0, :]  # we just use the top-1
-
-        pred_str = wordid2str(pred_ids.detach().cpu(), vocab)
-        return pred_str
-
-    def inference_forward(self, inference_args: dict, beam_size, topk=1, oov_dict=None):
-        """
-            Decoding with the support of beam_search.
-            Specifically, when ``beam_size`` is 1, it is equal to greedy search.
-        Parameters
-        ----------
-        inference_args: dict
-            The dict contains the arguments for the forward calculation pipeline during inference.
-            For most cases, it must contains a batch graph with key ``graph_data``.
-        beam_size: int
-            The beam width. When it is 1, the output is equal to greedy search's output.
-        topk: int, default=1
-            The number of decoded sequence to be reserved.
-            Usually, ``topk`` should be smaller or equal to ``beam_size``
-        oov_dict: VocabModel, default=None
-            The vocabulary for copy.
-
-        Returns
-        -------
-        results: torch.Tensor
-            The results with the shape of ``[batch_size, topk, max_decoder_step]`` containing the word indexes. # noqa
-        """
-        return self.translate(
-            batch_graph=inference_args["graph_data"],
-            beam_size=beam_size,
-            topk=topk,
-            oov_dict=oov_dict,
-        )
-
     @classmethod
     def from_args(cls, opt, vocab_model):
         """
@@ -312,11 +267,11 @@ class Graph2Seq(Graph2XBase):
         -------
         model: Graph2Seq
         """
-        initializer_args = cls._get_node_initializer_params(opt)
+        emb_args = cls._get_node_embedding_params(opt)
         gnn_args = cls._get_gnn_params(opt)
         dec_args = cls._get_decoder_params(opt)
 
-        args = copy.deepcopy(initializer_args)
+        args = copy.deepcopy(emb_args)
         args.update(gnn_args)
         args.update(dec_args)
         args["share_vocab"] = opt["graph_construction_args"]["graph_construction_share"][
@@ -354,14 +309,11 @@ class Graph2Seq(Graph2XBase):
         return ret
 
     @staticmethod
-    def _get_node_initializer_params(opt):
-        # Dynamic graph construction related params are stored here
-        init_args = opt["graph_construction_args"]["graph_construction_private"]
-        ret: dict = copy.deepcopy(init_args)
-        args = opt["graph_initialization_args"]
-        ret.update(args)
+    def _get_node_embedding_params(opt):
+        args = opt["graph_construction_args"]["node_embedding"]
+        ret: dict = copy.deepcopy(args)
         ret.pop("embedding_style")
         emb_ret = {"emb_" + key: value for key, value in ret.items()}
         emb_ret["embedding_style"] = args["embedding_style"]
-        emb_ret["graph_name"] = opt["graph_construction_name"]
+        emb_ret["graph_type"] = opt["graph_construction_name"]
         return emb_ret
