@@ -43,8 +43,25 @@ class ConstituencyBasedGraphConstruction(StaticGraphConstructionBase):
         Generate graph topology and embeddings.
     """
 
-    def __init__(self, vocab):
-        super(ConstituencyBasedGraphConstruction, self).__init__()
+    def __init__(
+        self,
+        embedding_style,
+        vocab,
+        hidden_size,
+        fix_word_emb=True,
+        fix_bert_emb=True,
+        word_dropout=None,
+        rnn_dropout=None,
+    ):
+        super(ConstituencyBasedGraphConstruction, self).__init__(
+            word_vocab=vocab,
+            embedding_styles=embedding_style,
+            hidden_size=hidden_size,
+            fix_word_emb=fix_word_emb,
+            fix_bert_emb=fix_bert_emb,
+            word_dropout=word_dropout,
+            rnn_dropout=rnn_dropout,
+        )
         self.vocab = vocab
 
     @classmethod
@@ -69,7 +86,7 @@ class ConstituencyBasedGraphConstruction(StaticGraphConstructionBase):
         return parsed_output
 
     @classmethod
-    def static_topology(
+    def topology(
         cls,
         raw_text_data,
         nlp_processor,
@@ -476,4 +493,5 @@ class ConstituencyBasedGraphConstruction(StaticGraphConstructionBase):
         return res_graph
 
     def forward(self, batch_graphdata: list):
-        raise RuntimeError("This interface is removed.")
+        batch_graphdata = self.embedding_layer(batch_graphdata)
+        return batch_graphdata
